Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Connector.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Connector.java	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Connector.java	(revision 2784)
@@ -21,5 +21,4 @@
 package net.fckeditor.connector;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.List;
@@ -31,4 +30,5 @@
 import net.fckeditor.connector.exception.InvalidCurrentFolderException;
 import net.fckeditor.connector.exception.InvalidNewFolderNameException;
+import net.fckeditor.connector.exception.ReadException;
 import net.fckeditor.connector.exception.WriteException;
 import net.fckeditor.handlers.ResourceType;
@@ -80,7 +80,9 @@
 	 * @return A list of folder names.
 	 * @throws InvalidCurrentFolderException
+	 * @throws ReadException
 	 */
 	public List<Map<String, Object>> getFiles(final ResourceType type,
-			final String currentFolder) throws InvalidCurrentFolderException;
+			final String currentFolder) throws InvalidCurrentFolderException,
+			ReadException;
 
 	/**
@@ -92,7 +94,9 @@
 	 * @return A list of file names.
 	 * @throws InvalidCurrentFolderException
+	 * @throws ReadException
 	 */
 	public List<String> getFolders(final ResourceType type,
-			final String currentFolder) throws InvalidCurrentFolderException;
+			final String currentFolder) throws InvalidCurrentFolderException,
+			ReadException;
 
 	/**
@@ -107,9 +111,11 @@
 	 * @throws InvalidNewFolderNameException
 	 * @throws FolderAlreadyExistsException
+	 * @throws WriteException
 	 */
 	public void createFolder(final ResourceType type,
 			final String currentFolder, final String newFolder)
 			throws InvalidCurrentFolderException,
-			InvalidNewFolderNameException, FolderAlreadyExistsException;
+			InvalidNewFolderNameException, FolderAlreadyExistsException,
+			WriteException;
 
 	/**
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Dispatcher.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Dispatcher.java	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/Dispatcher.java	(revision 2784)
@@ -32,4 +32,5 @@
 import net.fckeditor.connector.exception.InvalidCurrentFolderException;
 import net.fckeditor.connector.exception.InvalidNewFolderNameException;
+import net.fckeditor.connector.exception.ReadException;
 import net.fckeditor.connector.exception.WriteException;
 import net.fckeditor.handlers.Command;
@@ -108,9 +109,9 @@
 		// check parameters
 		if (!Command.isValidForGet(context.getCommandStr()))
-			getResponse = GetResponse.getErrorInvalidCommand();
+			getResponse = GetResponse.getInvalidCommandError();
 		else if (!ResourceType.isValidType(context.getTypeStr()))
-			getResponse = GetResponse.getErrorInvalidType();
+			getResponse = GetResponse.getInvalidResourceTypeError();
 		else if (!UtilsFile.isValidPath(context.getCurrentFolderStr()))
-			getResponse = GetResponse.getErrorInvalidCurrentFolder();
+			getResponse = GetResponse.getInvalidCurrentFolderError();
 		else {
 			
@@ -123,8 +124,8 @@
 					.equals(Command.GET_FOLDERS_AND_FILES))
 					&& !RequestCycleHandler.isEnabledForFileBrowsing(request))
-				getResponse = GetResponse.getErrorFileBrowsingDisabled();
+				getResponse = GetResponse.getGetResourcesDisabledError();
 			else if (command.equals(Command.CREATE_FOLDER)
 					&& !RequestCycleHandler.isEnabledForFolderCreation(request))
-				getResponse = GetResponse.getErrorFolderCreationDisabled();
+				getResponse = GetResponse.getCreateFolderDisabledError();
 			else {
 				// make the connector calls, catch its exceptions and generate
@@ -140,5 +141,5 @@
 						if (Utils.isEmpty(sanitizedNewFolderNameStr))
 							getResponse = GetResponse
-									.getErrorInvalidFolderName();
+									.getInvalidNewFolderNameError();
 						else {
 							logger.debug(
@@ -160,9 +161,13 @@
 					}
 				} catch (InvalidCurrentFolderException e) {
-					getResponse = GetResponse.getErrorInvalidCurrentFolder();
+					getResponse = GetResponse.getInvalidCurrentFolderError();
 				} catch (InvalidNewFolderNameException e) {
-					getResponse = GetResponse.getErrorInvalidFolderName();
+					getResponse = GetResponse.getInvalidNewFolderNameError();
 				} catch (FolderAlreadyExistsException e) {
-					getResponse = GetResponse.getErrorFolderAlreadyExists();
+					getResponse = GetResponse.getFolderAlreadyExistsError();
+				} catch (WriteException e) {
+					getResponse = GetResponse.getCreateFolderWriteError();
+				} catch (ReadException e) {
+					getResponse = GetResponse.getGetResourcesReadError();
 				}
 			}
@@ -187,8 +192,10 @@
 	 * @return
 	 * @throws InvalidCurrentFolderException
+	 * @throws ReadException 
 	 */
 	private GetResponse getFoldersAndOrFiles(final Command command,
 			final ResourceType type, final String currentFolderStr,
-			final String url) throws InvalidCurrentFolderException {
+			final String url) throws InvalidCurrentFolderException,
+			ReadException {
 		GetResponse getResponse = new GetResponse(command, type,
 				currentFolderStr, url);
@@ -228,12 +235,12 @@
 		// check permissions for user actions
 		if (!RequestCycleHandler.isEnabledForFileUpload(request))
-			uploadResponse = UploadResponse.getErrorFileUploadDisabled();
+			uploadResponse = UploadResponse.getFileUploadDisabledError();
 		// check parameters  
 		else if (!Command.isValidForPost(context.getCommandStr()))
-			uploadResponse = UploadResponse.getErrorInvalidCommand();
+			uploadResponse = UploadResponse.getInvalidCommandError();
 		else if (!ResourceType.isValidType(context.getTypeStr()))
-			uploadResponse = UploadResponse.getErrorInvalidType();
+			uploadResponse = UploadResponse.getInvalidResourceTypeError();
 		else if (!UtilsFile.isValidPath(context.getCurrentFolderStr()))
-			uploadResponse = UploadResponse.getErrorInvalidCurrentFolder();
+			uploadResponse = UploadResponse.getInvalidCurrentFolderError();
 		else {
 
@@ -254,10 +261,10 @@
 				if (type.isNotAllowedExtension(FilenameUtils
 						.getExtension(fileName)))
-					uploadResponse = UploadResponse.getErrorInvalidExtension();
+					uploadResponse = UploadResponse.getInvalidFileTypeError();
 				// Secure image check (can't be done if QuickUpload)
 				else if (type.equals(ResourceType.IMAGE)
 						&& PropertiesLoader.isSecureImageUploads()
 						&& !UtilsFile.isImage(uplFile.getInputStream())) {
-					uploadResponse = UploadResponse.getErrorInvalidExtension();
+					uploadResponse = UploadResponse.getInvalidFileTypeError();
 				} else {
 					String sanitizedFileName = UtilsFile
@@ -273,9 +280,7 @@
 
 					if (sanitizedFileName.equals(newFileName))
-						uploadResponse = new UploadResponse(
-								UploadResponse.SC_OK, fileUrl);
+						uploadResponse = UploadResponse.getOK(fileUrl);
 					else {
-						uploadResponse = new UploadResponse(
-								UploadResponse.SC_RENAMED, fileUrl, newFileName);
+						uploadResponse = UploadResponse.getFileRenamedWarning(fileUrl, newFileName);
 						logger.debug("Parameter NewFile (renamed): {}",
 								newFileName);
@@ -284,13 +289,11 @@
 				uplFile.delete();
 			} catch (InvalidCurrentFolderException e) {
-				uploadResponse = UploadResponse.getErrorInvalidCurrentFolder();
+				uploadResponse = UploadResponse.getInvalidCurrentFolderError();
 			} catch (WriteException e) {
-				uploadResponse = UploadResponse.getErrorUnknown();
-				// FIXME what response should be send back?
+				uploadResponse = UploadResponse.getFileUploadWriteError();
 			} catch (IOException e) {
-				// TODO handle it maybe better?!
-				uploadResponse = UploadResponse.getErrorUnknown();
+				uploadResponse = UploadResponse.getFileUploadWriteError();
 			} catch (FileUploadException e) {
-				uploadResponse = UploadResponse.getErrorUnknown();
+				uploadResponse = UploadResponse.getFileUploadWriteError();
 			}
 		}
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/ReadException.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/ReadException.java	(revision 2784)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/ReadException.java	(revision 2784)
@@ -0,0 +1,37 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.connector.exception;
+
+import net.fckeditor.connector.Dispatcher;
+import net.fckeditor.handlers.Command;
+
+/**
+ * Thrown to indicate that during some read action ({@link Command#GET_FOLDERS}
+ * or {@link Command#GET_FOLDERS_AND_FILES}) an error has occurred. These is an
+ * exception to signal the {@link Dispatcher} what was going wrong.
+ * 
+ * @version $Id$
+ */
+public class ReadException extends Exception {
+
+	private static final long serialVersionUID = 6418053231588982734L;
+
+}
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/LocalizedMessages.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/LocalizedMessages.java	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/handlers/LocalizedMessages.java	(revision 2784)
@@ -21,4 +21,5 @@
 package net.fckeditor.handlers;
 
+import java.text.MessageFormat;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -144,19 +145,19 @@
 
 	/**
-	 * Getter for localized <code>message.compatible_browser.yes</code> property
+	 * Getter for localized <code>message.editor.compatibleBrowser.yes</code> property
 	 * 
 	 * @return CompatibleBrowserYes
 	 */
-	public String getCompatibleBrowser() {
-		return getString("message.compatible_browser.yes");
-	}
-
-	/**
-	 * Getter for localized <code>message.compatible_browser.no</code> property
+	public String getCompatibleBrowserYes() {
+		return getString("message.editor.compatibleBrowser.yes");
+	}
+
+	/**
+	 * Getter for localized <code>message.editor.compatibleBrowser.no</code> property
 	 * 
 	 * @return CompatibleBrowserNo
 	 */
-	public String getNotCompatibleBrowser() {
-		return getString("message.compatible_browser.no");
+	public String getCompatibleBrowserNo() {
+		return getString("message.editor.compatibleBrowser.no");
 	}
 
@@ -180,43 +181,86 @@
 		return getString("message.connector.fileUpload.disabled");
 	}
-
-	/**
-	 * Getter for localized <code>message.connector.fileBrowsing.enabled</code>
-	 * property
-	 * 
-	 * @return FileBrowsingEnabled
-	 */
-	public String getFileBrowsingEnabled() {
-		return getString("message.connector.fileBrowsing.enabled");
-	}
-
-	/**
-	 * Getter for localized <code>message.connector.fileBrowsing.disabled</code>
-	 * property
-	 * 
-	 * @return FileBrowsingDisabled
-	 */
-	public String getFileBrowsingDisabled() {
-		return getString("message.connector.fileBrowsing.disabled");
-	}
-
-	/**
-	 * Getter for localized
-	 * <code>message.connector.folderCreation.enabled</code> property
+	
+	/**
+	 * Getter for localized <code>message.connector.file_renamed_warning</code>
+	 * property
+	 * 
+	 * @param newFileName the new filename
+	 * @return FileRenamedWarning
+	 */
+	public String getFileRenamedWarning(String newFileName) {
+		return MessageFormat.format(
+				getString("message.connector.fileUpload.file_renamed_warning"),
+				newFileName);
+	}
+	
+	/**
+	 * Getter for localized <code>message.connector.fileUpload.invalid_file_type_specified</code>
+	 * property
+	 * 
+	 * @return InvalidFileTypeSpecified
+	 */
+	public String getInvalidFileTypeSpecified() {
+		return getString("message.connector.fileUpload.invalid_file_type_specified");
+	}
+	
+	/**
+	 * Getter for localized
+	 * <code>message.connector.fileUpload.write_error</code> property
+	 * 
+	 * @return FileUploadWiteError
+	 */
+	public String getFileUploadWriteError() {
+		return getString("message.connector.fileUpload.write_error");
+	}
+
+	/**
+	 * Getter for localized <code>message.connector.getResources.enabled</code>
+	 * property
+	 * 
+	 * @return GetResourcesEnabled
+	 */
+	public String getGetResourcesEnabled() {
+		return getString("message.connector.getResources.enabled");
+	}
+
+	/**
+	 * Getter for localized <code>message.connector.getResources.disabled</code>
+	 * property
+	 * 
+	 * @return GetResourcesDisabled
+	 */
+	public String getGetResourcesDisabled() {
+		return getString("message.connector.getResources.disabled");
+	}
+	
+	/**
+	 * Getter for localized <code>message.connector.getResources.read_error</code>
+	 * property
+	 * 
+	 * @return GetResourcesReadError
+	 */
+	public String getGetResourcesReadError() {
+		return getString("message.connector.getResources.read_error");
+	}
+
+	/**
+	 * Getter for localized
+	 * <code>message.connector.createFolder.enabled</code> property
 	 * 
 	 * @return FolderCreationEnabled
 	 */
-	public String getFolderCreationEnabled() {
-		return getString("message.connector.folderCreation.enabled");
-	}
-
-	/**
-	 * Getter for localized
-	 * <code>message.connector.folderCreation.disabled</code> property
+	public String getCreateFolderEnabled() {
+		return getString("message.connector.createFolder.enabled");
+	}
+
+	/**
+	 * Getter for localized
+	 * <code>message.connector.createFolder.disabled</code> property
 	 * 
 	 * @return FolderCreationDisabled
 	 */
-	public String getFolderCreationDisabled() {
-		return getString("message.connector.folderCreation.disabled");
+	public String getCreateFolderDisabled() {
+		return getString("message.connector.createFolder.disabled");
 	}
 
@@ -227,26 +271,56 @@
 	 * @return InvalidCommandSpecified
 	 */
-	public String getInvalidCommand() {
+	public String getInvalidCommandSpecified() {
 		return getString("message.connector.invalid_command_specified");
 	}
-
-	/**
-	 * Getter for localized
-	 * <code>message.connector.invalid_type_specified</code> property
+	
+	/**
+	 * Getter for localized
+	 * <code>message.connector.createFolder.folder_already_exists_error</code> property
+	 * 
+	 * @return FolderAlreadyExistsError
+	 */
+	public String getFolderAlreadyExistsError() {
+		return getString("message.connector.createFolder.folder_already_exists_error");
+	}
+	
+	/**
+	 * Getter for localized
+	 * <code>message.connector.createFolder.invalid_new_folder_name_specified</code> property
+	 * 
+	 * @return InvalidNewFolderNameSpecified
+	 */
+	public String getInvalidNewFolderNameSpecified() {
+		return getString("message.connector.createFolder.invalid_new_folder_name_specified");
+	}
+	
+	/**
+	 * Getter for localized
+	 * <code>message.connector.createFolder.write_error</code> property
+	 * 
+	 * @return CreateFolderWriteError
+	 */
+	public String getCreateFolderWriteError() {
+		return getString("message.connector.createFolder.write_error");
+	}
+
+	/**
+	 * Getter for localized
+	 * <code>message.connector.invalid_resource_type_specified</code> property
 	 * 
 	 * @return InvalidTypeSpecified
 	 */
-	public String getInvalidType() {
-		return getString("message.connector.invalid_type_specified");
-	}
-
-	/**
-	 * Getter for localized
-	 * <code>message.connector.invalid_current_folder_speficied</code> property
+	public String getInvalidResouceTypeSpecified() {
+		return getString("message.connector.invalid_resource_type_specified");
+	}
+
+	/**
+	 * Getter for localized
+	 * <code>message.connector.invalid_current_folder_specified</code> property
 	 * 
 	 * @return InvalidCurrentFolderSpecified
 	 */
-	public String getInvalidCurrentFolder() {
-		return getString("message.connector.invalid_current_folder_speficied");
+	public String getInvalidCurrentFolderSpecified() {
+		return getString("message.connector.invalid_current_folder_specified");
 	}
 
Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/GetResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/GetResponse.java	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/GetResponse.java	(revision 2784)
@@ -67,6 +67,6 @@
 	public static final int EN_FOLDER_ALREADY_EXISTS_ERROR = 101;
 
-	/** Error number INVALID FOLDER NAME */
-	public static final int EN_INVALID_FOLDER_NAME_ERROR = 102;
+	/** Error number INVALID NEW FOLDER NAME */
+	public static final int EN_INVALID_NEW_FOLDER_NAME_ERROR = 102;
 
 	/** Error number SECURITY ERROR */
@@ -76,5 +76,4 @@
 	public static final int EN_UKNOWN_CREATE_FOLDER_ERROR = 110;
 	
-
 	/**
 	 * 
@@ -243,43 +242,54 @@
 	}
 	
-	public static GetResponse getErrorInvalidFolderName() {
-		return new GetResponse(EN_INVALID_FOLDER_NAME_ERROR);
-	}
-	
-	public static GetResponse getErrorInvalidCommand() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidCommand());
-	}
-	
-	public static GetResponse getErrorInvalidType() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidType());
-	}
-	
-	public static GetResponse getErrorInvalidCurrentFolder() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidCurrentFolder());
-	}
-	
-	public static GetResponse getErrorFolderAlreadyExists() {
-		return new GetResponse(EN_FOLDER_ALREADY_EXISTS_ERROR);
-	}
-	
-	public static GetResponse getErrorSecurity() {
-		return new GetResponse(EN_CREATE_FOLDER_SECURITY_ERROR);
-	}
-	
-	public static GetResponse getErrorFileBrowsingDisabled() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new GetResponse(EN_CUSTOM_ERROR, lm.getFileBrowsingDisabled());
-	}
-
-	public static GetResponse getErrorFolderCreationDisabled() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new GetResponse(EN_CUSTOM_ERROR, lm.getFolderCreationDisabled());
-	}
-	
-	public static GetResponse getErrorUnknown() {
-		return new GetResponse(EN_UKNOWN_CREATE_FOLDER_ERROR);
+	public static GetResponse getInvalidCommandError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidCommandSpecified());
+	}
+	
+	public static GetResponse getInvalidResourceTypeError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidResouceTypeSpecified());
+	}
+	
+	public static GetResponse getInvalidCurrentFolderError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getInvalidCurrentFolderSpecified());
+	}
+	
+	// TODO which EN to respond?
+	public static GetResponse getGetResourcesDisabledError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getGetResourcesDisabled());
+	}
+	
+	// TODO which EN to respond?
+	public static GetResponse getGetResourcesReadError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getGetResourcesReadError());
+	}
+	
+	// TODO which EN to respond?
+	public static GetResponse getCreateFolderDisabledError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_CUSTOM_ERROR, lm.getCreateFolderDisabled());
+	}
+	
+	public static GetResponse getInvalidNewFolderNameError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_INVALID_NEW_FOLDER_NAME_ERROR, lm
+				.getInvalidNewFolderNameSpecified());
+	}
+	
+	public static GetResponse getFolderAlreadyExistsError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_FOLDER_ALREADY_EXISTS_ERROR, lm
+				.getFolderAlreadyExistsError());
+	}
+	
+	// TODO which EN to respond?
+	public static GetResponse getCreateFolderWriteError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new GetResponse(EN_UKNOWN_CREATE_FOLDER_ERROR, lm
+				.getCreateFolderWriteError());
 	}
 }
Index: FCKeditor.Java/trunk/java-core/src/main/resources/META-INF/FCKeditor.tld
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/resources/META-INF/FCKeditor.tld	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/resources/META-INF/FCKeditor.tld	(revision 2784)
@@ -112,6 +112,6 @@
 			<description>
 				Provide the feature name you want to check. Valid
-				features are [FileUpload, FileBrowsing,	CompatibleBrowser,
-				FolderCreation]
+				features are [FileUpload, GetResources, FileBrowsing (deprecated),
+				CompatibleBrowser, CreateFolder, FolderCreation (deprecated)]
 			</description>
 			<name>command</name>
Index: FCKeditor.Java/trunk/java-core/src/main/resources/net/fckeditor/handlers/default.properties
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/resources/net/fckeditor/handlers/default.properties	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/resources/net/fckeditor/handlers/default.properties	(revision 2784)
@@ -67,14 +67,21 @@
 
 # default messages (localizable)
-message.compatible_browser.no = Your browser is not compatible
-message.compatible_browser.yes = Your browser is fully compatible
+message.editor.compatibleBrowser.no = Your browser is not compatible
+message.editor.compatibleBrowser.yes = Your browser is fully compatible
 
 message.connector.fileUpload.disabled = You are not authorized to upload files!
 message.connector.fileUpload.enabled = You are authorized to upload files!
-message.connector.fileBrowsing.disabled = You are not authorized to browse files!
-message.connector.fileBrowsing.enabled = You are authorized to browse files!
-message.connector.folderCreation.disabled = You are not authorized to create folders!
-message.connector.folderCreation.enabled = You are authorized to create folders!
+message.connector.fileUpload.file_renamed_warning = Your file was uploaded successfully but has been renamed to \\''{0}\\''.
+message.connector.fileUpload.invalid_file_type_specified = The uploaded has a wrong file type (extension).
+message.connector.fileUpload.write_error = The specified file could not be uploaded successfully, please try again!
+message.connector.getResources.disabled = You are not authorized to browse/list files and/or folders!
+message.connector.getResources.enabled = You are authorized to browse/list files and/or folders!
+message.connector.getResources.read_error = The selected resources could not be read successfully, please try again!
+message.connector.createFolder.disabled = You are not authorized to create folders!
+message.connector.createFolder.enabled = You are authorized to create folders!
+message.connector.createFolder.invalid_new_folder_name_specified = Invalid new folder name specified
+message.connector.createFolder.folder_already_exists_error = The specified folder already exists
+message.connector.createFolder.write_error = The specified folder could not be created successfully, please try again!
 message.connector.invalid_command_specified = Invalid command specified
-message.connector.invalid_type_specified = Invalid resource type specified
-message.connector.invalid_current_folder_speficied = Invalid current folder specified
+message.connector.invalid_resource_type_specified = Invalid resource type specified
+message.connector.invalid_current_folder_specified = Invalid current folder specified

Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/WriteException.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/WriteException.java	(revision 2783)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/connector/exception/WriteException.java	(revision 2784)
@@ -22,9 +22,12 @@
 
 import net.fckeditor.connector.Dispatcher;
+import net.fckeditor.handlers.Command;
 
 /**
  * Thrown to indicate that during file write action an error has occured.
  * These is an exception to signal the {@link Dispatcher} what was going wrong.
  *
  * @version $Id$
  */
@@ -22,9 +22,12 @@
 
 /**
- * Thrown to indicate that during file write action an error has occured.
- * These is an exception to signal the {@link Dispatcher} what was going wrong.
- *
+ * Thrown to indicate that during some write action (
+ * {@link Command#CREATE_FOLDER}, {@link Command#FILE_UPLOAD} or
+ * {@link Command#QUICK_UPLOAD}) an error has occurred. These is an exception to
+ * signal the {@link Dispatcher} what was going wrong.
+ * 
  * @version $Id$
  */